/*
 * GDSII-Converter Python Plugin
 * Copyright (C) 2020  Mario Hüttel <mario.huettel@gmx.net>
 *
 * This file is part of GDSII-Converter.
 *
 * GDSII-Converter is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * GDSII-Converter is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GDSII-Converter. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @file python-renderer/glist.c
 * @author Mario Hüttel <mario.huettel@gmx.net>
 */

/**
 * @defgroup python-plugin-glist GList wrapper for python
 * @ingroup python-plugin
 * This is a wrapping class for GLists
 * This wrpper acts as a read only access to the lists
 *
 * @addtogroup python-plugin-glist
 * @{
 */

#include <python-renderer/glist.h>

struct _GListObject {
	PyObject_HEAD
	GList *head;
	size_t len;
};

static PyObject *glist_to_list(GListObject *self, PyObject *Py_UNUSED(ignored))
{
	return Py_BuildValue("");
}

static PyMethodDef glist_methods[] = {
	{"tolist", (PyCFunction)glist_to_list, METH_NOARGS, "Convert GList to editable list"}
};

void glist_set_head_ptr(GListObject *self, GList *head)
{
	if (!self || !head)
		return;

	self->head = head;
	self->len = g_list_length(self->head);
}

PyTypeObject GListType = {
	PyVarObject_HEAD_INIT(NULL, 0)
	.tp_name = "gds_render.GList",
	.tp_doc = "Read only GList",
	.tp_basicsize = sizeof(GListObject),
	.tp_itemsize = 0,
	.tp_flags = Py_TPFLAGS_DEFAULT,
	.tp_new = PyType_GenericNew,
	.tp_methods = glist_methods
};

/** @} */
